@@ -7,7 +7,7 @@
 // #include "ogr_spatialref.h" // for OGRSpatialReference
 // #include "cpl_conv.h" // for CPLFree()
 
-#include "gdalheaders/gdalheaders.h"
+#include "gdallibrary/gdallibrary.h"
 namespace gdalgeometry {
 using namespace Rcpp;
 
@@ -52,6 +52,12 @@ inline CharacterVector gdal_geometry_txt(OGRFeature *poFeature, CharacterVector
   CPLFree(export_txt);
   return txt;
 }
+inline IntegerVector gdal_geometry_type(OGRFeature*poFeature) {
+    OGRwkbGeometryType gtyp = OGR_G_GetGeometryType( poFeature->GetGeometryRef());
+    Rcpp::IntegerVector r_gtyp = Rcpp::IntegerVector(1);
+     r_gtyp[0] = (int)gtyp;
+    return r_gtyp;
+}
 inline NumericVector gdal_geometry_extent(OGRFeature *poFeature) {
   OGREnvelope env;
   OGR_G_GetEnvelope(poFeature->GetGeometryRef(), &env);
@@ -76,7 +82,13 @@ inline NumericVector gdal_geometry_extent(OGRFeature *poFeature) {
 
 /// READ FIDS ----------------------------------------------------------------------------
 inline NumericVector layer_read_fids_all(OGRLayer *poLayer) {
-  double   nFeature = gdalheaders::force_layer_feature_count(poLayer);
+  //double   nFeature = gdallibrary::force_layer_feature_count(poLayer);
+  // trying to fix SQL problem 2020-10-05
+  double nFeature = poLayer->GetFeatureCount();
+  if (nFeature < 1) {
+    Rprintf("force count\n");
+    nFeature = gdallibrary::force_layer_feature_count(poLayer);
+  }
 
   NumericVector out(nFeature);
   std::fill( out.begin(), out.end(), NumericVector::get_na() );
@@ -99,7 +111,7 @@ inline NumericVector dsn_read_fids_all(CharacterVector dsn, IntegerVector layer,
   {
     Rcpp::stop("Open failed.\n");
   }
-  OGRLayer *poLayer = gdalheaders::gdal_layer(poDS, layer, sql = sql, ex =  ex);
+  OGRLayer *poLayer = gdallibrary::gdal_layer(poDS, layer, sql, ex);
   NumericVector out = layer_read_fids_all(poLayer);
   // clean up if SQL was used https://www.gdal.org/classGDALDataset.html#ab2c2b105b8f76a279e6a53b9b4a182e0
   if (sql[0] != "") {
@@ -141,7 +153,7 @@ inline NumericVector dsn_read_fids_ij(CharacterVector dsn, IntegerVector layer,
   {
     Rcpp::stop("Open failed.\n");
   }
-  OGRLayer *poLayer = gdalheaders::gdal_layer(poDS, layer, sql = sql, ex =  ex);
+  OGRLayer *poLayer = gdallibrary::gdal_layer(poDS, layer, sql, ex);
   NumericVector out = layer_read_fids_ij(poLayer, ij);
   // clean up if SQL was used https://www.gdal.org/classGDALDataset.html#ab2c2b105b8f76a279e6a53b9b4a182e0
   if (sql[0] != "") {
@@ -183,7 +195,7 @@ inline NumericVector dsn_read_fids_ia(CharacterVector dsn, IntegerVector layer,
   {
     Rcpp::stop("Open failed.\n");
   }
-  OGRLayer *poLayer = gdalheaders::gdal_layer(poDS, layer, sql = sql, ex =  ex);
+  OGRLayer *poLayer = gdallibrary::gdal_layer(poDS, layer, sql, ex);
   NumericVector out = layer_read_fids_ia(poLayer, ia);
   // clean up if SQL was used https://www.gdal.org/classGDALDataset.html#ab2c2b105b8f76a279e6a53b9b4a182e0
   if (sql[0] != "") {
@@ -202,14 +214,20 @@ inline NumericVector dsn_read_fids_ia(CharacterVector dsn, IntegerVector layer,
 inline List layer_read_geom_all(OGRLayer *poLayer, CharacterVector format) {
   OGRFeature *poFeature;
   poLayer->ResetReading();
-  int nFeature = gdalheaders::force_layer_feature_count(poLayer);
+  //int nFeature = gdallibrary::force_layer_feature_count(poLayer);
+  // trying to fix SQL problem 2020-10-05
+  double nFeature = poLayer->GetFeatureCount();
+  if (nFeature < 1) {
+    Rprintf("force count\n");
+    nFeature = gdallibrary::force_layer_feature_count(poLayer);
+  }
 
   List out(nFeature);
   double ii = 0;
   while( (poFeature = poLayer->GetNextFeature()) != NULL ) {
     // work through format
     // FIXME: get rid of "geometry"
-    if (format[0] == "wkb" | format[0] == "geometry") {
+    if ((format[0] == "wkb") | (format[0] == "geometry")) {
       out[ii] = gdal_geometry_raw(poFeature);
     }
     if (format[0] == "wkt") {
@@ -220,9 +238,12 @@ inline List layer_read_geom_all(OGRLayer *poLayer, CharacterVector format) {
       out[ii] = gdal_geometry_extent(poFeature);
     }
     // these are all just text variants (wkt uses a different mech)
-    if (format[0] == "gml" | format[0] == "json" | format[0] == "kml") {
+    if ((format[0] == "gml") | (format[0] == "json") | (format[0] == "kml")) {
       out[ii] = gdal_geometry_txt(poFeature, format);
     }
+    if (format[0] == "type") {
+      out[ii] = gdal_geometry_type(poFeature);
+    }
 
     OGRFeature::DestroyFeature(poFeature);
     ii++;
@@ -240,7 +261,7 @@ inline List dsn_read_geom_all(CharacterVector dsn, IntegerVector layer,
   {
     Rcpp::stop("Open failed.\n");
   }
-  OGRLayer *poLayer = gdalheaders::gdal_layer(poDS, layer, sql = sql, ex =  ex);
+  OGRLayer *poLayer = gdallibrary::gdal_layer(poDS, layer, sql, ex);
   List out = layer_read_geom_all(poLayer, format);
   // clean up if SQL was used https://www.gdal.org/classGDALDataset.html#ab2c2b105b8f76a279e6a53b9b4a182e0
   if (sql[0] != "") {
@@ -267,7 +288,7 @@ inline List layer_read_geom_ij(OGRLayer *poLayer, CharacterVector format, Numeri
 
       // work through format
       // FIXME: get rid of "geometry"
-      if (format[0] == "wkb" | format[0] == "geometry") {
+      if ((format[0] == "wkb") | (format[0] == "geometry")) {
         out[cnt] = gdal_geometry_raw(poFeature);
       }
       if (format[0] == "wkt") {
@@ -278,9 +299,12 @@ inline List layer_read_geom_ij(OGRLayer *poLayer, CharacterVector format, Numeri
         out[cnt] = gdal_geometry_extent(poFeature);
       }
       // these are all just text variants (wkt uses a different mech)
-      if (format[0] == "gml" | format[0] == "json" | format[0] == "kml") {
+      if ((format[0] == "gml") | (format[0] == "json") | (format[0] == "kml")) {
         out[cnt] = gdal_geometry_txt(poFeature, format);
       }
+      if (format[0] == "type") {
+        out[ii] = gdal_geometry_type(poFeature);
+      }
       cnt++;
 
     }
@@ -300,7 +324,7 @@ inline List dsn_read_geom_ij(CharacterVector dsn, IntegerVector layer,
   {
     Rcpp::stop("Open failed.\n");
   }
-  OGRLayer *poLayer = gdalheaders::gdal_layer(poDS, layer, sql = sql, ex =  ex);
+  OGRLayer *poLayer = gdallibrary::gdal_layer(poDS, layer, sql, ex);
   List out = layer_read_geom_ij(poLayer, format, ij);
   // clean up if SQL was used https://www.gdal.org/classGDALDataset.html#ab2c2b105b8f76a279e6a53b9b4a182e0
   if (sql[0] != "") {
@@ -327,7 +351,7 @@ inline List layer_read_geom_ia(OGRLayer *poLayer, CharacterVector format, Numeri
 
       // work through format
       // FIXME: get rid of "geometry"
-      if (format[0] == "wkb" | format[0] == "geometry") {
+      if ((format[0] == "wkb") | (format[0] == "geometry")) {
         out[cnt] = gdal_geometry_raw(poFeature);
       }
       if (format[0] == "wkt") {
@@ -338,9 +362,12 @@ inline List layer_read_geom_ia(OGRLayer *poLayer, CharacterVector format, Numeri
         out[cnt] = gdal_geometry_extent(poFeature);
       }
       // these are all just text variants (wkt uses a different mech)
-      if (format[0] == "gml" | format[0] == "json" | format[0] == "kml") {
+      if ((format[0] == "gml") | (format[0] == "json") | (format[0] == "kml")) {
         out[cnt] = gdal_geometry_txt(poFeature, format);
       }
+      if (format[0] == "type") {
+        out[ii] = gdal_geometry_type(poFeature);
+      }
       cnt++;
 
     }
@@ -360,7 +387,7 @@ inline List dsn_read_geom_ia(CharacterVector dsn, IntegerVector layer,
   {
     Rcpp::stop("Open failed.\n");
   }
-  OGRLayer *poLayer = gdalheaders::gdal_layer(poDS, layer, sql = sql, ex =  ex);
+  OGRLayer *poLayer = gdallibrary::gdal_layer(poDS, layer, sql, ex);
   List out = layer_read_geom_ia(poLayer, format, ia);
   // clean up if SQL was used https://www.gdal.org/classGDALDataset.html#ab2c2b105b8f76a279e6a53b9b4a182e0
   if (sql[0] != "") {
@@ -383,7 +410,7 @@ inline List layer_read_geom_fa(OGRLayer *poLayer, CharacterVector format, Numeri
     poFeature = poLayer->GetFeature(feature_id);
     // work through format
     // FIXME: get rid of "geometry"
-    if (format[0] == "wkb" | format[0] == "geometry") {
+    if ((format[0] == "wkb") | (format[0] == "geometry")) {
       out[ii] = gdal_geometry_raw(poFeature);
     }
     if (format[0] == "wkt") {
@@ -394,10 +421,12 @@ inline List layer_read_geom_fa(OGRLayer *poLayer, CharacterVector format, Numeri
       out[ii] = gdal_geometry_extent(poFeature);
     }
     // these are all just text variants (wkt uses a different mech)
-    if (format[0] == "gml" | format[0] == "json" | format[0] == "kml") {
+    if ((format[0] == "gml") | (format[0] == "json") | (format[0] == "kml")) {
       out[ii] = gdal_geometry_txt(poFeature, format);
     }
-
+    if (format[0] == "type") {
+      out[ii] = gdal_geometry_type(poFeature);
+    }
     OGRFeature::DestroyFeature(poFeature);
   }
   return out;
@@ -413,7 +442,7 @@ inline List dsn_read_geom_fa(CharacterVector dsn, IntegerVector layer,
   {
     Rcpp::stop("Open failed.\n");
   }
-  OGRLayer *poLayer = gdalheaders::gdal_layer(poDS, layer, sql = sql, ex =  ex);
+  OGRLayer *poLayer = gdallibrary::gdal_layer(poDS, layer, sql, ex);
   List out = layer_read_geom_fa(poLayer, format, fa);
   // clean up if SQL was used https://www.gdal.org/classGDALDataset.html#ab2c2b105b8f76a279e6a53b9b4a182e0
   if (sql[0] != "") {
@@ -428,11 +457,17 @@ inline List dsn_read_geom_fa(CharacterVector dsn, IntegerVector layer,
 
 /// READ FIELDS ----------------------------------------------------------------------------
 inline List layer_read_fields_all(OGRLayer *poLayer, CharacterVector fid_column_name) {
-  double   nFeature = gdalheaders::force_layer_feature_count(poLayer);
+  //double   nFeature = gdallibrary::force_layer_feature_count(poLayer);
+  // trying to fix SQL problem 2020-10-05
+  double nFeature = poLayer->GetFeatureCount();
+  if (nFeature < 0) {
+    Rprintf("force count\n");
+    nFeature = gdallibrary::force_layer_feature_count(poLayer);
+  }
 
   OGRFeatureDefn *poFDefn = poLayer->GetLayerDefn();
   bool int64_as_string = false;
-  List out = gdalheaders::allocate_fields_list(poFDefn, nFeature, int64_as_string, fid_column_name);
+  List out = gdallibrary::allocate_fields_list(poFDefn, nFeature, int64_as_string, fid_column_name);
 
   OGRFeature *poFeature;
   double ii = 0;
@@ -480,7 +515,7 @@ inline List dsn_read_fields_all(CharacterVector dsn, IntegerVector layer,
   {
     Rcpp::stop("Open failed.\n");
   }
-  OGRLayer *poLayer = gdalheaders::gdal_layer(poDS, layer, sql = sql, ex =  ex);
+  OGRLayer *poLayer = gdallibrary::gdal_layer(poDS, layer, sql, ex);
   List out = layer_read_fields_all(poLayer, fid_column_name);
   // clean up if SQL was used https://www.gdal.org/classGDALDataset.html#ab2c2b105b8f76a279e6a53b9b4a182e0
   if (sql[0] != "") {
@@ -497,7 +532,7 @@ inline List layer_read_fields_ij(OGRLayer *poLayer, CharacterVector fid_column_n
 
   OGRFeatureDefn *poFDefn = poLayer->GetLayerDefn();
   bool int64_as_string = false;
-  List out = gdalheaders::allocate_fields_list(poFDefn, nFeature, int64_as_string, fid_column_name);
+  List out = gdallibrary::allocate_fields_list(poFDefn, nFeature, int64_as_string, fid_column_name);
 
   OGRFeature *poFeature;
 
@@ -552,7 +587,7 @@ inline List dsn_read_fields_ij(CharacterVector dsn, IntegerVector layer,
   {
     Rcpp::stop("Open failed.\n");
   }
-  OGRLayer *poLayer = gdalheaders::gdal_layer(poDS, layer, sql = sql, ex =  ex);
+  OGRLayer *poLayer = gdallibrary::gdal_layer(poDS, layer, sql, ex);
   List out = layer_read_fields_ij(poLayer, fid_column_name, ij);
   // clean up if SQL was used https://www.gdal.org/classGDALDataset.html#ab2c2b105b8f76a279e6a53b9b4a182e0
   if (sql[0] != "") {
@@ -570,7 +605,7 @@ inline List layer_read_fields_ia(OGRLayer *poLayer, CharacterVector fid_column_n
 
   OGRFeatureDefn *poFDefn = poLayer->GetLayerDefn();
   bool int64_as_string = false;
-  List out = gdalheaders::allocate_fields_list(poFDefn, nFeature, int64_as_string, fid_column_name);
+  List out = gdallibrary::allocate_fields_list(poFDefn, nFeature, int64_as_string, fid_column_name);
 
   OGRFeature *poFeature;
 
@@ -625,7 +660,7 @@ inline List dsn_read_fields_ia(CharacterVector dsn, IntegerVector layer,
   {
     Rcpp::stop("Open failed.\n");
   }
-  OGRLayer *poLayer = gdalheaders::gdal_layer(poDS, layer, sql = sql, ex =  ex);
+  OGRLayer *poLayer = gdallibrary::gdal_layer(poDS, layer, sql, ex);
   List out = layer_read_fields_ia(poLayer, fid_column_name, ia);
   // clean up if SQL was used https://www.gdal.org/classGDALDataset.html#ab2c2b105b8f76a279e6a53b9b4a182e0
   if (sql[0] != "") {
@@ -644,7 +679,7 @@ inline List layer_read_fields_fa(OGRLayer *poLayer, CharacterVector fid_column_n
 
   OGRFeatureDefn *poFDefn = poLayer->GetLayerDefn();
   bool int64_as_string = false;
-  List out = gdalheaders::allocate_fields_list(poFDefn, nFeature, int64_as_string, fid_column_name);
+  List out = gdallibrary::allocate_fields_list(poFDefn, nFeature, int64_as_string, fid_column_name);
 
   OGRFeature *poFeature;
   double cnt = 0;
@@ -696,7 +731,7 @@ inline List dsn_read_fields_fa(CharacterVector dsn, IntegerVector layer,
   {
     Rcpp::stop("Open failed.\n");
   }
-  OGRLayer *poLayer = gdalheaders::gdal_layer(poDS, layer, sql = sql, ex =  ex);
+  OGRLayer *poLayer = gdallibrary::gdal_layer(poDS, layer, sql, ex);
   List out = layer_read_fields_fa(poLayer, fid_column_name, fa);
   // clean up if SQL was used https://www.gdal.org/classGDALDataset.html#ab2c2b105b8f76a279e6a53b9b4a182e0
   if (sql[0] != "") {
